@@ -3,7 +3,7 @@
 # NorthernLight.pm
 # by Jim Smyser
 # Copyright (C) 1996-1999 by Jim Smyser & USC/ISI
-# $Id: NorthernLight.pm,v 1.2 1999/06/21 15:35:44 mthurn Exp $
+# $Id: NorthernLight.pm,v 1.7 1999/07/14 13:20:28 mthurn Exp $
 
 package WWW::Search::NorthernLight;
 
@@ -22,8 +22,8 @@ WWW::Search::NorthernLight - class for searching NorthernLight
     while (my $oResult = $oSearch->next_result()) {
         print $oResult->url, "\n";
     }
-=head1 DESCRIPTION
 
+=head1 DESCRIPTION
 
 This class is a NorthernLight specialization of WWW::Search.
 It handles making and interpreting NorthernLight searches
@@ -62,24 +62,11 @@ set of results, otherwise it sets it to undef to indicate we''re done.
 =head1 TESTING
 
 This module adheres to the C<WWW::Search> test suite mechanism. 
-
-    $file = 'test/NorthernLight/zero_result';
-    $query = $bogus_query;
-    test($mode, $TEST_EXACTLY);
-
-    $file = 'test/NorthernLight/one_page_result';
-    $query = '+Bi' . 'athlon +weltcups +Athleten +deutschland';
-    test($mode, $TEST_RANGE, 2, 25);
-
-    # 25 hits/page
-    $file = 'test/NorthernLight/two_page_result';
-    $query = '+LS' . 'AM +ISI +IB';
-    test($mode, $TEST_GREATER_THAN, 25);
-
+See $TEST_CASES below.
 
 =head1 AUTHOR
-This Backend is will now be maintained and supported by Jim Smyser.
 
+This Backend is will now be maintained and supported by Jim Smyser.
 Flames to: <jsmyser@bigfoot.com>
 
 C<WWW::Search::NorthernLight> was originally written by Andreas Borchert
@@ -94,6 +81,18 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 
 =head1 VERSION HISTORY
+
+2.01
+typo and new test mechanism
+
+1.06
+Slight reformat change.
+
+1.05
+Fixed 'next' page tag recognition, this changed slightly. 
+Whitespace removal in description that was really BAD with
+some hits. Ignoring internal NorthernLight URL's.
+
 1.04
 Slight adjustments to formatting. Returning score and date
 with description.
@@ -110,8 +109,14 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search Exporter);
-$VERSION = '1.04';
+$VERSION = '2.01';
 
+$MAINTAINER = 'Jim Smyser <jsmyser@bigfoot.com>';
+$TEST_CASES = <<"ENDTESTCASES";
+&test('NorthernLight', '$MAINTAINER', 'zero', \$bogus_query, \$TEST_EXACTLY);
+&test('NorthernLight', '$MAINTAINER', 'one_page', '+Bi'.'athlon +wel'.'tcups +Ath'.'leten +deuts'.'chland', \$TEST_RANGE, 2,25);
+&test('NorthernLight', '$MAINTAINER', 'two_page', '+LS'.'AM +IS'.'I', \$TEST_GREATER_THAN, 26);
+ENDTESTCASES
 
 use Carp ();
 use WWW::Search(generic_option);
@@ -162,7 +167,7 @@ sub native_setup_search {
 sub native_retrieve_some
     {
     my ($self) = @_;
-    print STDERR "**NorthernLight::native_retrieve_some()\n" if $self->{_debug};
+    print STDERR "**NorthernLight::native_retrieve_some()**\n" if $self->{_debug};
     
     # Fast exit if already done:
     return undef if (!defined($self->{_next_url}));
@@ -190,40 +195,49 @@ sub native_retrieve_some
       {
      next if m@^$@; # short circuit for blank lines
      print STDERR " $state ===$_=== " if 2 <= $self->{'_debug'};
-     if (m|(\d+) items|i) {
-       print STDERR "Total Pages Returned\n" if ($self->{_debug});
+     if (m|(\d+)\sitems|i) {
+       print STDERR "**Found Header Count**\n" if ($self->{_debug});
+       $self->approximate_result_count($1);
        $state = $START;
   } elsif ($state eq $START && m{<!-- result -->}i) {
        print STDERR "Found START line\n" if 2 <= $self->{_debug};
        $state = $HITS;
-  } if ($state eq $HITS && m@<a href="(.*?)">(.*?)</a><br>@i) {
-       print STDERR "hit url line\n" if 2 <= $self->{_debug};
-       if (defined($hit)) 
+  } if ($state eq $HITS && m@<td.*?><font.*?><a href="(.*?)">(.*?)</a><br>@i) {
+       print STDERR "**Found Hit URL**\n" if 2 <= $self->{_debug};
+       my ($URL, $Title) = ($1,$2);
+       # ignore NorthernLights own URL's.
+       if ($URL ne 'http://special.northernlight.com')
+          {
+     if (defined($hit)) 
          {
          push(@{$self->{cache}}, $hit);
          };
        $hit = new WWW::SearchResult;
-       $hit->add_url($1);
+       $hit->add_url($URL);
        $hits_found++;
-       $hit->title($2);
+       $hit->title($Title);
        $state = $DESC;
-
+       } #URL does eq
       # score and date is returned with the description. 
-    } elsif ($state eq $DESC && m|<!.*?>(.*)<br>|i) {
-       print STDERR "Description line\n" if 2 <= $self->{_debug};
-       $hit->description($1);
+  } elsif ($state eq $DESC && m|^(<b>(.*))<br>|i) {
+       print STDERR "**Found Description**\n" if 2 <= $self->{_debug};
+       my ($description) = ($1);
+       # Don't desire this, remove it if found.
+       $description =~ s/<!--NLResultRelevanceEnd-->//g;
+       # There can be a great deal of whitespaces in the desc, so much
+       # that a one line desc can displace over 20 lines! Remove em.
+       $description =~ s/\s+/ /g;
+       $hit->description($description);
        $state = $HITS;
-
-   } elsif ($state eq $HITS && m|<td valign=middle><a href="(.*)">,
-     <img src="(.*)alt="Next Page"></a></td>|i) {
-       print STDERR "Next line\n" if 2 <= $self->{_debug};
-       my $sURL = $1;
-       $self->{'_next_to_retrieve'} = $1 if $sURL =~ m/first=(\d+)/;
-       $self->{'_next_url'} = $self->{'search_base_url'} . $sURL;
+  } elsif ($state eq $HITS && m@.*?<a href="(.*)"><img src="(.*)alt="Next Page"></a>@i) {
+       print STDERR "**Going to Next Page**\n" if 2 <= $self->{_debug};
+       my $URL = $1;
+       # $self->{'_next_to_retrieve'} = $1;   # Martin Thurn commented this out.  _next_to_retrieve is supposed to be an integer.
+       $self->{'_next_url'} = $self->{'search_base_url'} . $URL;
        print STDERR "Next URL is ", $self->{'_next_url'}, "\n" if 2 <= $self->{_debug};
        $state = $HITS;
        } else {
-       print STDERR "Nothing matched.\n" if 2 <= $self->{_debug};
+       print STDERR "**Nothing matched.**\n" if 2 <= $self->{_debug};
        }
   } if (defined($hit)) {
      push(@{$self->{cache}}, $hit);
@@ -231,5 +245,3 @@ sub native_retrieve_some
    return $hits_found;
    } # native_retrieve_some
  1;
-
-
